#[non_exhaustive]pub enum ErrorKind {
Peripheral,
InvalidSpeed,
Other,
}Expand description
Fan error kind.
This represents a common set of Fan operation errors. HAL implementations are free to define more specific or additional error types. However, by providing a mapping to these common Fan errors, generic code can still react to them.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Peripheral
An error occurred on the underlying peripheral supporting the fan. e.g. A PWM error occured for a PWM-controlled fan or a DAC error occured for a voltage-controlled fan.
InvalidSpeed
The fan is not capable of operating at the requested speed.
Other
A different error occurred. The original error may contain more information.