Error

Trait Error 

pub trait Error: Debug {
    // Required method
    fn kind(&self) -> ErrorKind;
}
Fan error.

Required Methods

fn kind(&self) -> ErrorKind

Convert error to a generic Fan error kind.

By using this method, Fan errors freely defined by HAL implementations can be converted to a set of generic Fan errors upon which generic code can act.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Error for Infallible

Source

fn kind(&self) -> ErrorKind

Implementors